/***************************************************************************
                          db_2_gui.h  -  description
                             -------------------
    begin                : Fri Nov 30 2001
    copyright            : (C) 2001 by Denis Lackovic
    email                : delacko@fly.srk.fer.hr
 ***************************************************************************/

#define DB_NAME "database.db"
#define CONF_NAME "transdict.conf"

#include <string.h>
#include <stdio.h>
#include<iostream.h>


#include <qfile.h>
#include <qmultilineedit.h>
#include <qtable.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qmessagebox.h>
#include <qlist.h>
#include <qdir.h>
//#include "db.h"
#include "main_interface.h"
#include "additional_functions.h"
#include "sqlite.h"
#include <pgsql/libpq++.h>

#ifdef _WS_X11_
	#include <stdlib.h>
#endif

#ifndef DB_2_GUI_H
#define DB_2_GUI_H
class message{
	public:
		QString comm;  // coment (#. comment)
		QString flag; // which kind of translation is it (fuzzy, c-format,...)
		QString refNo; //file name and line number from which translation was taken
		QString msgId; //expression to be translated
		QString msgStr; //translation of the expression
		QString msgType; // which type of translation is it (msgid-msgstr, #~msgid-#~msgstr,plural)

		message(QString c, QString f,QString r, QString mi, QString ms,QString mt){
			comm=c; 
			flag=f; 
			refNo=r;
			msgId=mi;
			msgStr=ms;
			msgType=mt;
		}
		message(){}
		~message(){}
		void reset(){
			comm="";
			flag="";
			refNo=""; 
			msgId="";
			msgStr="";
			msgType="";
		}
};

      class db_to_gui:public Form1
{

        Q_OBJECT

        public:
                db_to_gui( QWidget* parent = 0, const char* name = 0,
                               /* bool modal = FALSE,*/ WFlags f = 0 ) :
                        Form1 ( parent, name, /*modal,*/ f ) {
				QString databasePath="";
				QString databaseDir="";
				
				//for unix
				#ifdef _WS_X11_
				//if enviroment variable $TDHOME defined we try to open database "database.db" in directory $TDHOME
				databasePath=getenv("TDHOME");
				if(databasePath.length()==0){
					databasePath=getenv("HOME");
				}
				databasePath+="/transdict";

				QDir dbDir(databasePath);
				if (!dbDir.exists()){
					if(!dbDir.mkdir(databasePath,TRUE)){
						QMessageBox::information( 0, "Error creating TransDict directory " ,"Could not create directory \n\""+databasePath+ "\\nin which TransDict database should be saved  ", QMessageBox::Ok );                
					}
//					cout <<"stvaram direktorij " <<databasePath<<endl;
				}
				databaseDir=databasePath;
			
				databasePath+="/";
				databasePath+=DB_NAME;
				#else
				//for windows o mac
				databasePath=DB_NAME;
				#endif



				setTDHome(databaseDir);
				
				
				#ifdef _WS_X11_
				setTDConf(databaseDir +"/"+CONF_NAME);
				#else 
				setTDConf(CONF_NAME);
				#endif

				bool doit=FALSE;
				QFile dbf(getTDConf());
				if(!dbf.exists()){
					doit=TRUE;
				}


				
				
//				cout <<"direktorij baze " <<databasePath <<endl;
				char *errmesg;
				//here we initialize local database
				database= sqlite_open(databasePath.latin1(), 0, &errmesg);
				if(database==NULL){
						QMessageBox::information( 0, "Error opening local TransDict database ","Error opening local TransDict database \n\""+databasePath +"\n"+errmesg, QMessageBox::Ok );
				}
				else if(doit){
					//creating sample tables, sample configuration file
					createSampleConfiguration(getTDConf());
				}
//					cout <<"file postoji: " <<databasePath<<endl;
				free(errmesg);
				
				connectedToDb=FALSE;
				//here we set some initial gui (e.g. table column names, getting information out of configuration file)
				init();

			}
	private:
		//this is local database pointer
		sqlite *database;
		//online database pointer (postgresql)
		PgDatabase *onlineDb;
		bool connectedToDb;
		
		//this class contains information of current dictionary
		DictDescription curDict;

		
		//this class contains information of current dictionary fields, indexes, etc.
		DictType curDType;
		//this list contains descriptions of all dictionary types and dictionaries that belong to each individual type
		QList<DictType> dTypes;

		//this class contains other user configuration options
		Cfg conf;

		QString transDictHome;
		QString transDictConf;


                public slots:
                        void on_edit_dictionary();
                        void create_new_dictionary();
                        void on_dictionary_changed(const QString &);
                        void on_dictionary_type_changed(const QString &);
			void on_save_configuration();
			void on_export_to_po_file();
			void on_user_info_change();
                        void on_cell_changed(int x, int y);
                        void on_save_translations();
                        void on_copy_expression_to_translation();
                        void on_add_new_row();
                        void on_delete_row();
                        void on_clear_table();
			void on_get_new_expressions();
                        void on_search_cell_changed(int, int);

			void on_sync_local_to_server();
			void on_sync_server_to_local();
			void on_local_to_table();
			void on_server_to_table();
			void on_save_table_to_local();
			void on_save_table_to_server();


			//used to calculate insert and update queries on table when on save_table_to{local|server} 
			//are called. If local=TRUE query is sent to local database, if local=FALSE query is sent to remote
			//database
			void insert_query_to_database(bool local);
			void find_type(QString fieldName, QString &fieldType);
			int insert_into_dictionary(QString sqlText);
			int getColumnsAndValues(QTable *table, int row,QStringList &columns, QStringList &values);
			int parse_po_file(QList<message> &m,QString fN, QString enc);
			void on_import_from_po_file();
			int import_from_po_file(QList<message> &m);
			//if local==true messages are searched in local database
			int export_po_file(QList<message> &m,QString fN, bool local, QString enc,QString cop);
 
			//this method is called manually or on initialization to make conection
			//to online dictionary, if warn is TRUE message will popup if error occurs
			void connect_to_online_dictionary(bool warn);
                        void init();
                        void createSampleConfiguration(QString dir);
                        bool isConnected();
                        void setConnected();
                        void sendReturnToCell();
			QString currentDictionaryType();
			
			QString getTDHome();
			void setTDHome(QString dir);
			QString getTDConf();
			void setTDConf(QString file);
																								
};

#endif
